utf16_length_from_latin1

Function utf16_length_from_latin1 

pub fn utf16_length_from_latin1(src_len: usize) -> usize
Count the number of code units that the Latin1 string would require in UTF-16 format.

This function does not validate the input. It is acceptable to pass invalid Latin1 strings but in such cases the result is implementation defined.