pub fn utf32_length_from_utf16be(src: &[u16]) -> usizeExpand description
Count the number of code units that the UTF-16BE string would require in UTF-32 format.
This function is equivalent to count_utf16be.
This function is not BOM-aware.
This function does not validate the input. It is acceptable to pass invalid UTF-16BE strings but in such cases the result is implementation defined.